==> phpicalendar-2.1.tgz: phpicalendar/languages/japanese.inc.php <==
<?php

// English language include
// For version 2.0 PHP iCalendar
//
// Translation by Jared Wangen (jared@silter.org)
// With the help of Eri Hayashiguchi
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= '日';
$lang['l_week'] 			= '週';
$lang['l_month'] 			= '月';
$lang['l_year'] 			= '年';
$lang['l_calendar'] 		= 'カレンダー';
$lang['l_next_day'] 		= '翌日';
$lang['l_next_month'] 		= '来月';
$lang['l_next_week'] 		= '来週';
$lang['l_next_year'] 		= '来年';
$lang['l_last_day'] 		= '前日';
$lang['l_last_month'] 		= '先月';
$lang['l_last_week'] 		= '先週';
$lang['l_last_year'] 		= '去年';
$lang['l_subscribe'] 		= '追加';
$lang['l_download'] 		= 'ダウンロード';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= '件名';
$lang['l_event_start'] 		= '開始日';
$lang['l_event_end'] 		= '終了日';
$lang['l_this_months'] 		= '今月の予定';
$lang['l_date'] 			= '日付';
$lang['l_summary'] 			= '件名';
$lang['l_all_day'] 			= '終日イベント';
$lang['l_notes'] 			= '注釈';
$lang['l_this_years'] 		= '今年の予定';
$lang['l_today'] 			= '今日';
$lang['l_this_week'] 		= '今週';
$lang['l_this_month'] 		= '今月';
$lang['l_jump'] 			= '移動';
$lang['l_tomorrows'] 		= '明日の予定';
$lang['l_goday'] 			= '今日に移動';
$lang['l_goweek'] 			= '今週に移動';
$lang['l_gomonth'] 			= '今月に移動';
$lang['l_goyear'] 			= '今年に移動';
$lang['l_search'] 			= '検索'; // the verb
$lang['l_results'] 			= '検索結果';
$lang['l_query'] 			= '検索キーワード'; // will be followed by the search query
$lang['l_no_results'] 		= '一致する予定はありませんでした。';
$lang['l_goprint'] 			= '印刷用表示';
$lang['l_time'] 			= '時間';
$lang['l_summary'] 			= '要約';
$lang['l_description'] 		= 'メモ';
$lang['l_this_site_is']		= 'This site is';
$lang['l_no_events_day']	= '今日は予定がありません。';
$lang['l_no_events_week']	= '今週は予定がありません。';
$lang['l_no_events_month']	= '今月は予定がありません。';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date	']	= '%b %e日';  // Lists just the day
$lang['l_rss_month_date	']	= '%b %e日';  // Lists just the day
$lang['l_rss_language']		= 'ja';
$lang['l_search_took']		= '検索に%s秒かかりました。';
$lang['l_recurring_event']	= '引き続く予定';
$lang['l_exception']		= '特例';
$lang['l_no_query']			= '検索キーワードがありませんでした。';
$lang['l_preferences']		= '環境設定';
$lang['l_printer']			= 'プリンター';
$lang['l_select_lang']		= 'デフォルト言語を選択して下さい';
$lang['l_select_cal']		= 'デフォルトカレンダーを選択して下さい';
$lang['l_select_view']		= 'デフォルト見解を選択して下さい';
$lang['l_select_time']		= 'デフォルト開始時刻を選択して下さい';
$lang['l_select_day']		= 'デフォルト開始曜日を選択して下さい';
$lang['l_select_style']		= 'デフォルト形式を選択して下さい';
$lang['l_set_prefs']		= '環境設定を保存する';
$lang['l_completed_date']	= '%sに完成された。';
$lang['l_completed']		= '完了';
$lang['l_created']			= '作成日:';
$lang['l_due']				= '期限:';
$lang['l_priority']			= '優先順位:';
$lang['l_priority_high']	= '高い';
$lang['l_priority_low']		= '低い';
$lang['l_priority_medium']	= '普通';
$lang['l_priority_none']	= 'なし';
$lang['l_status']			= '状態';
$lang['l_todo']				= '備忘録';
$lang['l_unfinished']		= '完成されていない';
$lang['l_prefs_set'] 		= 'Your preferences have been set.';
$lang['l_prefs_unset'] 		= 'Preferences unset. Changes will take place next page load.';
$lang['l_unset_prefs'] 		= '保存された設定を削除する';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_location']			= 'Location';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Username';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Wrong username or password.';
$lang['l_addupdate_cal']	= 'Add or Update a Calendar';
$lang['l_addupdate_desc']	= 'Add a calendar by uploading a new file. Update a calendar by uploading a file of the same name.';
$lang['l_delete_cal']		= 'Delete a Calendar';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Calendar File';
$lang['l_php_error']		= 'PHP Error';
$upload_error_gen_lang		= 'There was a problem with your upload.';
$upload_error_lang[0]		= 'There was a problem with your upload.';
$upload_error_lang[1]		= 'The file you are trying to upload is too big.';
$upload_error_lang[2]		= 'The file you are trying to upload is too big.';
$upload_error_lang[3]		= 'The file you are trying upload was only partially uploaded.';
$upload_error_lang[4]		= 'You must select a file for upload.';
$lang['l_upload_error_type'] = 'Only .ics files may be uploaded.';
$lang['l_copy_error']			= 'Failed to copy file';
$lang['l_delete_error']			= 'Failed to delete file';
$lang['l_delete_success']		= 'was deleted successfully.';
$lang['l_action_success']		= 'Your action was successful.';
$lang['l_submit']				= 'Submit';
$lang['l_delete']				= 'Delete';
$all_cal_comb_lang			= 'All Combined';

// New for 2.0
$lang['l_legend']			= '凡例';
$lang['l_admin_subhead']	= 'Manage your calendars from this page';
$lang['l_prefs_subhead']	= 'このサイトを見るためのクッキーを設定します';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] 		= '戻る';
$lang['l_next'] 		= '次';
$lang['l_prev'] 		= '前';
$lang['l_day_view'] 	= '日';
$lang['l_week_view'] 	= '週';
$lang['l_month_view'] 	= '月';
$lang['l_year_view'] 	= '年';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('年','年');		// for these, put singular
$format_recur_lang['monthly']		= array('か月','か月');		// and plural forms
$format_recur_lang['weekly']		= array('週','週');		// these will be %freq%
$format_recur_lang['daily']			= array('日','日');			// in the replacement below
$format_recur_lang['hourly']		= array('時間','時間');
$format_recur_lang['minutely']		= array('分','分');
$format_recur_lang['secondly']		= array('秒','秒');

$format_recur_lang['start']			= '%int%%freq%ごとに%for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= '%date%まで';				// ie, 'until January 4'
$format_recur_lang['count']			= '%int%回';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= '月：%list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= '日：%list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= '曜日：%list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('日曜日','月曜日','火曜日','水曜日','木曜日','金曜日','土曜日');
$daysofweekshort_lang		= array ('日','月','火','水','木','金','土');
$daysofweekreallyshort_lang	= array ('日','月','火','水','木','金','土');
$monthsofyear_lang			= array ('1月','2月','3月','4月','5月','6月','7月','8月','9月','10月','11月','12月');
$monthsofyearshort_lang		= $monthsofyear_lang;

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'g:i A';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%B%e日 %A';
$dateFormat_week = '%B%e日';
$dateFormat_week_list = '%b%e日（%a）';
$dateFormat_week_jump = '%b%e日';
$dateFormat_month = '%Y年%B';
$dateFormat_month_list = '%B%e日 %A';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'エラー!';
$lang['l_error_window'] 		= 'エラーが発生しました!';
$lang['l_error_calendar'] 		= 'エラーがおきたとき、「%s」カレンダーを処理していました。';
$lang['l_error_path'] 			= '「%s」ディレクトリを開けることはできません。';
$lang['l_error_back'] 			= '前のページに戻るには「戻る」ボタンをクリックして下さい。';
$lang['l_error_remotecal'] 		= 'このサーバは承認されていないリモートカレンダーを拒否しています。';
$lang['l_error_restrictedcal'] 	= 'このサーバで 限られているカレンダーにアクセスしようとしました。';
$lang['l_error_invalidcal'] 	= 'Invalid calendar file. Please try a different calendar.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';

?>

==> phpicalendar-2.31p4.tgz: phpicalendar/languages/japanese.inc.php <==
<?php

// English language include
// For version 2.0 PHP iCalendar
//
// Translation by Jared Wangen (jared@silter.org)
// With the help of Eri Hayashiguchi
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= '日';
$lang['l_week'] 			= '週';
$lang['l_month'] 			= '月';
$lang['l_year'] 			= '年';
$lang['l_calendar'] 		= 'カレンダー';
$lang['l_next_day'] 		= '翌日';
$lang['l_next_month'] 		= '来月';
$lang['l_next_week'] 		= '来週';
$lang['l_next_year'] 		= '来年';
$lang['l_last_day'] 		= '前日';
$lang['l_last_month'] 		= '先月';
$lang['l_last_week'] 		= '先週';
$lang['l_last_year'] 		= '去年';
$lang['l_subscribe'] 		= '追加';
$lang['l_download'] 		= 'ダウンロード';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= '件名';
$lang['l_event_start'] 		= '開始日';
$lang['l_event_end'] 		= '終了日';
$lang['l_this_months'] 		= '今月の予定';
$lang['l_date'] 			= '日付';
$lang['l_summary'] 			= '件名';
$lang['l_all_day'] 			= '終日イベント';
$lang['l_notes'] 			= '注釈';
$lang['l_this_years'] 		= '今年の予定';
$lang['l_today'] 			= '今日';
$lang['l_this_week'] 		= '今週';
$lang['l_this_month'] 		= '今月';
$lang['l_jump'] 			= '移動';
$lang['l_tomorrows'] 		= '明日の予定';
$lang['l_goday'] 			= '今日に移動';
$lang['l_goweek'] 			= '今週に移動';
$lang['l_gomonth'] 			= '今月に移動';
$lang['l_goyear'] 			= '今年に移動';
$lang['l_search'] 			= '検索'; // the verb
$lang['l_results'] 			= '検索結果';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query'] 			= '検索キーワード'; // will be followed by the search query
$lang['l_no_results'] 		= '一致する予定はありませんでした。';
$lang['l_goprint'] 			= '印刷用表示';
$lang['l_time'] 			= '時間';
$lang['l_summary'] 			= '要約';
$lang['l_description'] 		= 'メモ';
$lang['l_this_site_is']		= 'This site is';
$lang['l_no_events_day']	= '今日は予定がありません。';
$lang['l_no_events_week']	= '今週は予定がありません。';
$lang['l_no_events_month']	= '今月は予定がありません。';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date	']	= '%b %e日';  // Lists just the day
$lang['l_rss_month_date	']	= '%b %e日';  // Lists just the day
$lang['l_rss_language']		= 'ja';
$lang['l_search_took']		= '検索に%s秒かかりました。';
$lang['l_recurring_event']	= '引き続く予定';
$lang['l_exception']		= '特例';
$lang['l_no_query']			= '検索キーワードがありませんでした。';
$lang['l_preferences']		= '環境設定';
$lang['l_printer']			= 'プリンター';
$lang['l_select_lang']		= 'デフォルト言語を選択して下さい';
$lang['l_select_cal']		= 'デフォルトカレンダーを選択して下さい';
$lang['l_select_view']		= 'デフォルト見解を選択して下さい';
$lang['l_select_time']		= 'デフォルト開始時刻を選択して下さい';
$lang['l_select_day']		= 'デフォルト開始曜日を選択して下さい';
$lang['l_select_style']		= 'デフォルト形式を選択して下さい';
$lang['l_set_prefs']		= '環境設定を保存する';
$lang['l_completed_date']	= '%sに完成された。';
$lang['l_completed']		= '完了';
$lang['l_created']			= '作成日:';
$lang['l_due']				= '期限:';
$lang['l_priority']			= '優先順位:';
$lang['l_priority_high']	= '高い';
$lang['l_priority_low']		= '低い';
$lang['l_priority_medium']	= '普通';
$lang['l_priority_none']	= 'なし';
$lang['l_status']			= '状態';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= '備忘録';
$lang['l_unfinished']		= '完成されていない';
$lang['l_prefs_set'] 		= 'Your preferences have been set.';
$lang['l_prefs_unset'] 		= 'Preferences unset. Changes will take place next page load.';
$lang['l_unset_prefs'] 		= '保存された設定を削除する';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_location']			= 'Location';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Username';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Wrong username or password.';
$lang['l_addupdate_cal']	= 'Add or Update a Calendar';
$lang['l_addupdate_desc']	= 'Add a calendar by uploading a new file. Update a calendar by uploading a file of the same name.';
$lang['l_delete_cal']		= 'Delete a Calendar';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Calendar File';
$lang['l_php_error']		= 'PHP Error';
$upload_error_gen_lang		= 'There was a problem with your upload.';
$upload_error_lang[0]		= 'There was a problem with your upload.';
$upload_error_lang[1]		= 'The file you are trying to upload is too big.';
$upload_error_lang[2]		= 'The file you are trying to upload is too big.';
$upload_error_lang[3]		= 'The file you are trying upload was only partially uploaded.';
$upload_error_lang[4]		= 'You must select a file for upload.';
$lang['l_upload_error_type'] = 'Only .ics files may be uploaded.';
$lang['l_copy_error']			= 'Failed to copy file';
$lang['l_delete_error']			= 'Failed to delete file';
$lang['l_delete_success']		= 'was deleted successfully.';
$lang['l_action_success']		= 'Your action was successful.';
$lang['l_submit']				= 'Submit';
$lang['l_delete']				= 'Delete';
$all_cal_comb_lang			= 'All Combined';

// New for 2.0
$lang['l_legend']			= '凡例';
$lang['l_admin_subhead']	= 'Manage your calendars from this page';
$lang['l_prefs_subhead']	= 'このサイトを見るためのクッキーを設定します';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] 		= '戻る';
$lang['l_next'] 		= '次';
$lang['l_prev'] 		= '前';
$lang['l_day_view'] 	= '日';
$lang['l_week_view'] 	= '週';
$lang['l_month_view'] 	= '月';
$lang['l_year_view'] 	= '年';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('年','年');		// for these, put singular
$format_recur_lang['monthly']		= array('か月','か月');		// and plural forms
$format_recur_lang['weekly']		= array('週','週');		// these will be %freq%
$format_recur_lang['daily']			= array('日','日');			// in the replacement below
$format_recur_lang['hourly']		= array('時間','時間');
$format_recur_lang['minutely']		= array('分','分');
$format_recur_lang['secondly']		= array('秒','秒');

$format_recur_lang['start']			= '%int%%freq%ごとに%for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= '%date%まで';				// ie, 'until January 4'
$format_recur_lang['count']			= '%int%回';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= '月：%list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= '日：%list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= '曜日：%list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('日曜日','月曜日','火曜日','水曜日','木曜日','金曜日','土曜日');
$daysofweekshort_lang		= array ('日','月','火','水','木','金','土');
$daysofweekreallyshort_lang	= array ('日','月','火','水','木','金','土');
$monthsofyear_lang			= array ('1月','2月','3月','4月','5月','6月','7月','8月','9月','10月','11月','12月');
$monthsofyearshort_lang		= $monthsofyear_lang;

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'g:i A';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%B%e日 %A';
$dateFormat_week = '%B%e日';
$dateFormat_week_list = '%b%e日（%a）';
$dateFormat_week_jump = '%b%e日';
$dateFormat_month = '%Y年%B';
$dateFormat_month_list = '%B%e日 %A';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'エラー!';
$lang['l_error_window'] 		= 'エラーが発生しました!';
$lang['l_error_calendar'] 		= 'エラーがおきたとき、「%s」カレンダーを処理していました。';
$lang['l_error_path'] 			= '「%s」ディレクトリを開けることはできません。';
$lang['l_error_back'] 			= '前のページに戻るには「戻る」ボタンをクリックして下さい。';
$lang['l_error_remotecal'] 		= 'このサーバは承認されていないリモートカレンダーを拒否しています。';
$lang['l_error_restrictedcal'] 	= 'このサーバで 限られているカレンダーにアクセスしようとしました。';
$lang['l_error_invalidcal'] 	= 'Invalid calendar file. Please try a different calendar.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';

?>
